__author__ = 'zuoqin'

import cos2
import os
if __name__ == '__main__':

    access_key_id = os.getenv("COS_TEST_ACCESS_KEY_ID")
    access_key_secret = os.getenv("COS_TEST_ACCESS_KEY_SECRET")
    bucket_name = os.getenv("COS_TEST_ENDPOINT")
    endpoint = os.getenv("COS_TEST_BUCKET")

# Init COS Python SDK





# -*- coding: utf-8 -*-

import os
import shutil

import cos2


# 以下代码展示了基本的文件上传、下载、罗列、删除用法。


# 首先初始化AccessKeyId、AccessKeySecret、Endpoint等信息。
# 通过环境变量获取，或者把诸如“<你的AccessKeyId>”替换成真实的AccessKeyId等。

access_key_id = os.getenv("COS_TEST_ACCESS_KEY_ID")
access_key_secret = os.getenv("COS_TEST_ACCESS_KEY_SECRET")
bucket_name = os.getenv("COS_TEST_ENDPOINT")
endpoint = os.getenv("COS_TEST_BUCKET")



# 创建Bucket对象，所有Object相关的接口都可以通过Bucket对象来进行
bucket = cos2.Bucket(cos2.Auth(access_key_id, access_key_secret), endpoint, bucket_name)



# -*- coding: utf-8 -*-

import  cos2
import uuid
import os

if __name__ == '__main__':

    accessKeyId = os.getenv("COS_TEST_ACCESS_KEY_ID")
    accessKeySecret = os.getenv("COS_TEST_ACCESS_KEY_SECRET")
    bucket_name = os.getenv("COS_TEST_ENDPOINT")
    endpoint = os.getenv("COS_TEST_BUCKET")

    bucketName = 'my-first-cos-bucket-' + str(uuid.uuid1())
    objectName = 'my-first-cos-object.txt'

# print bucketName
    print '==========================================='
    print 'Getting Started with COS SDK for Python'
    print '===========================================\n'

# Init COS Python SDK
    auth = cos2.Auth(accessKeyId, accessKeySecret)
    bucket = cos2.Bucket(auth, endpoint, bucketName)

# Create a new COS PublicRead bucket
    print 'Creating bucket ' + bucketName
# bucket.create_bucket(cos2.BUCKET_ACL_PUBLIC_READ)
    bucket.create_bucket()

# List the buckets in your account
    print 'Listing buckets'
    service = cos2.Service(auth, endpoint, connect_timeout=30)
    for bucketInfo in service.list_buckets().buckets:
        print ' - ' + bucketInfo.name

# Upload an object to your bucket
    print 'Uploading a new object to COS from memory'
    content = 'Thank you for using COS SDK for Python'
    bucket.put_object(objectName, content)


# Determine whether an object residents in your bucket
    exist = bucket.object_exists(objectName)

    print exist
    print(bucket.get_object(objectName).read())






# -*- coding: utf-8 -*-

import os
from datetime import datetime

import cos2


# 以下代码展示了一些和文件相关的高级用法，如中文、设置用户自定义元数据、拷贝文件、追加上传等。


# 首先初始化AccessKeyId、AccessKeySecret、Endpoint等信息。
# 通过环境变量获取，或者把诸如“<你的AccessKeyId>”替换成真实的AccessKeyId等。
access_key_id = os.getenv("COS_TEST_ACCESS_KEY_ID")
access_key_secret = os.getenv("COS_TEST_ACCESS_KEY_SECRET")
bucket_name = os.getenv("COS_TEST_ENDPOINT")
endpoint = os.getenv("COS_TEST_BUCKET")

# 创建Bucket对象，所有Object相关的接口都可以通过Bucket对象来进行
